@@ -29,9 +29,11 @@ distributeMarkers = function(x, n = NULL, dist = NULL, chromLen = NULL,
                              alleles = 1:2, afreq = NULL, prefix = "M") {
 
   if(!length(chromLen)) {
-    chromLen = c(246.98258, 241.01465, 197.08100, 188.84446, 180.22043, 169.42632, 158.18255,
-                 143.83232, 136.96897, 132.52836, 133.86230, 132.11300, 94.68256, 85.03331, 77.41597,
-                 89.03333, 81.90883, 79.11141, 57.31905, 63.19036, 32.01867, 33.16128)
+    chromLen = c(248.956422, 242.193529, 198.295559, 190.214555, 181.538259,
+                 170.805979, 159.345973, 145.138636, 138.394717, 133.797422,
+                 135.086622, 133.275309, 114.364328, 107.043718, 101.991189,
+                 90.338345, 83.257441, 80.373285, 58.617616, 64.444167,
+                 46.709983, 50.818468)
   }
   chromNames = names(chromLen) %||% as.character(seq_along(chromLen))
 
@@ -102,7 +104,8 @@ distributeMarkers = function(x, n = NULL, dist = NULL, chromLen = NULL,
 #' Create and attach a list of empty SNP markers with specified position and
 #' allele frequencies.
 #'
-#' The data frame `snpData` should contain the following columns, in order:
+#' The first 6 columns of `snpData` should be as follows, in order. (The column
+#' names do not matter.)
 #'
 #' * `CHROM`: Chromosome (character)
 #'
@@ -116,14 +119,17 @@ distributeMarkers = function(x, n = NULL, dist = NULL, chromLen = NULL,
 #'
 #' * `FREQ1`: Allele frequency of `A1` (number in `[0,1]`)
 #'
-#' The actual column names do not matter.
-#'
 #' Each column must be of the stated type, or coercible to it. (For example,
 #' `CHROM`, `A1` and `A2` may be given as numbers, but will be internally
 #' converted to characters.)
 #'
+#' Subsequent columns are assumed to contain genotypes. These columns must be
+#' named with the IDs matching individuals in `x`. The genotypes must use the
+#' alleles given in `A1` and `A2`, and can be formatted with or without
+#' separator, e.g. `A/C` or `AC`.
+#'
 #' @param x A `ped` object.
-#' @param snpData A data frame with 6 columns. See Details.
+#' @param snpData A data frame with at least 6 columns. See Details.
 #'
 #' @return A copy of `x` with the indicated SNP markers attached.
 #'
@@ -135,9 +141,12 @@ distributeMarkers = function(x, n = NULL, dist = NULL, chromLen = NULL,
 #'   MB     = c(1.23, 2.34),
 #'   A1     = c("A", "G"),
 #'   A2     = c("C", "C"),
-#'   FREQ1  = c(0.7, 0.12))
+#'   FREQ1  = c(0.7, 0.12),
+#'   `2`    = c("A/C", "G/C"),
+#'   check.names = FALSE)       # Note: `check.names = FALSE`!
 #'
 #' x = setSNPs(nuclearPed(), snpData = snps)
+#' x
 #'
 #' # Inspect the results:
 #' getMap(x)
@@ -149,18 +158,12 @@ setSNPs = function(x, snpData) {
 
   if(is.pedList(x))
     return(lapply(x, function(y) setSNPs(y, snpData)))
+
   if(!is.ped(x))
     stop2("Argument `x` is not a ped object: ", class(x))
 
-  if(!is.data.frame(snpData) || ncol(snpData) != 6)
-    stop2("`snpData` must be a data frame with 6 columns. See ?setSNPs")
-
-  names(snpData) = toupper(names(snpData))
-
-  # If all names present, but possibly wrong order: sort
-  nms = c("CHROM", "MARKER", "MB", "A1", "A2", "FREQ1")
-  if(setequal(nms, names(snpData)))
-    snpData = snpData[nms]
+  if(!is.data.frame(snpData) || ncol(snpData) < 6)
+    stop2("`snpData` must be a data frame with at least 6 columns. See ?setSNPs")
 
   # Columns
   CHROM = as.character(snpData[[1]])
@@ -189,18 +192,50 @@ setSNPs = function(x, snpData) {
   sex = getSex(x)
   amat = matrix(0L, ncol = 2, nrow = pedsize(x))
 
+  # Genotype columns
+  ids = names(snpData)[-(1:6)] |> .myintersect(x$ID)
+  if(hasGeno <- length(ids) > 0) {
+    idsInt = internalID(x, ids)
+
+    # 1st allele (0/1) of each indiv
+    num1 = lapply(ids, function(id) substr(snpData[[id]], 1, 1) != A1)
+
+    # 2nd allele: extract character 2 or 3 (if sep e.g. a/b)
+    # TODO: ad hoc
+    b = sapply(ids, function(id) nchar(snpData[1, id])) |> .setnames(ids)
+    num2 = lapply(ids, function(id) substr(snpData[[id]], b[id], b[id]) != A1)
+
+    num1 = do.call(rbind, num1)
+    num2 = do.call(rbind, num2)
+
+    # Sort genotypes
+    if(any(swap <- num1 > num2)) {
+      tmp = num1[swap]
+      num1[swap] = num2[swap]
+      num2[swap] = tmp
+    }
+
+    # Single matrix with 1/2; column i corresponds to mi[idsInt, ]
+    gnum = rbind(num1, num2) + 1
+  }
+
   # Construct markers
-  mlist = lapply(seq_along(MARKER), function(i)
-    newMarker(amat, alleles = c(A1[i], A2[i]), afreq = c(FREQ1[i], 1 - FREQ1[i]),
-              name = MARKER[i], chrom = CHROM[i], posMb = MB[i], pedmembers = labs, sex = sex)
-  )
+  mlist = lapply(seq_along(MARKER), function(i) {
+    als = c(A1[i], A2[i])
+    afreq = c(FREQ1[i], 1 - FREQ1[i])
+    amati = amat
+    if(hasGeno)
+      amati[idsInt, ] = gnum[, i]
+
+    newMarker(amati, alleles = als, afreq = afreq, name = MARKER[i],
+              chrom = CHROM[i], posMb = MB[i], pedmembers = labs, sex = sex)
+  })
 
   class(mlist) = "markerList"
   setMarkers(x, mlist, checkCons = FALSE)
 }
 
 
-
 .setSNPfreqs = function(x, freq1) {
   if(!is.numeric(freq1))
     stop2("Argument `freq1` must be numeric, not ", class(freq1)[1])
@@ -235,3 +270,4 @@ setSNPs = function(x, snpData) {
 
   x
 }
+
